@@ -4,26 +4,27 @@
 
 import calendar
 import time
-
+from datetime import datetime, timezone
 from email.utils import formatdate, parsedate
-from datetime import datetime
+from pprint import pprint
+from unittest.mock import Mock
 
-from mock import Mock
 from requests import Session, get
 
 from cachecontrol import CacheControl
-from cachecontrol.heuristics import LastModified, ExpiresAfter, OneDayCache
-from cachecontrol.heuristics import TIME_FMT
-from cachecontrol.heuristics import BaseHeuristic
+from cachecontrol.heuristics import (
+    TIME_FMT,
+    BaseHeuristic,
+    ExpiresAfter,
+    LastModified,
+    OneDayCache,
+)
+
 from .utils import DummyResponse
 
-from pprint import pprint
-
-
-class TestHeuristicWithoutWarning(object):
-
-    def setup(self):
 
+class TestHeuristicWithoutWarning:
+    def setup_method(self):
         class NoopHeuristic(BaseHeuristic):
             warning = Mock()
 
@@ -35,17 +36,14 @@ class TestHeuristicWithoutWarning(object):
 
     def test_no_header_change_means_no_warning_header(self, url):
         the_url = url + "optional_cacheable_request"
-        resp = self.sess.get(the_url)
+        self.sess.get(the_url)
 
         assert not self.heuristic.warning.called
 
 
-class TestHeuristicWith3xxResponse(object):
-
-    def setup(self):
-
+class TestHeuristicWith3xxResponse:
+    def setup_method(self):
         class DummyHeuristic(BaseHeuristic):
-
             def update_headers(self, resp):
                 return {"x-dummy-header": "foobar"}
 
@@ -62,17 +60,15 @@ class TestHeuristicWith3xxResponse(object):
         assert "x-dummy-header" in resp.headers
 
 
-class TestUseExpiresHeuristic(object):
-
+class TestUseExpiresHeuristic:
     def test_expires_heuristic_arg(self):
         sess = Session()
         cached_sess = CacheControl(sess, heuristic=Mock())
         assert cached_sess
 
 
-class TestOneDayCache(object):
-
-    def setup(self):
+class TestOneDayCache:
+    def setup_method(self):
         self.sess = Session()
         self.cached_sess = CacheControl(self.sess, heuristic=OneDayCache())
 
@@ -90,9 +86,8 @@ class TestOneDayCache(object):
         assert r.from_cache
 
 
-class TestExpiresAfter(object):
-
-    def setup(self):
+class TestExpiresAfter:
+    def setup_method(self):
         self.sess = Session()
         self.cache_sess = CacheControl(self.sess, heuristic=ExpiresAfter(days=1))
 
@@ -111,9 +106,8 @@ class TestExpiresAfter(object):
         assert r.from_cache
 
 
-class TestLastModified(object):
-
-    def setup(self):
+class TestLastModified:
+    def setup_method(self):
         self.sess = Session()
         self.cached_sess = CacheControl(self.sess, heuristic=LastModified())
 
@@ -135,12 +129,11 @@ def datetime_to_header(dt):
     return formatdate(calendar.timegm(dt.timetuple()))
 
 
-class TestModifiedUnitTests(object):
-
+class TestModifiedUnitTests:
     def last_modified(self, period):
         return time.strftime(TIME_FMT, time.gmtime(self.time_now - period))
 
-    def setup(self):
+    def setup_method(self):
         self.heuristic = LastModified()
         self.time_now = time.time()
         day_in_seconds = 86400
@@ -164,7 +157,9 @@ class TestModifiedUnitTests(object):
         resp = DummyResponse(200, {"Date": self.now, "Last-Modified": self.week_ago})
         modified = self.heuristic.update_headers(resp)
         assert ["expires"] == list(modified.keys())
-        assert datetime(*parsedate(modified["expires"])[:6]) > datetime.now()
+
+        expected = datetime(*parsedate(modified["expires"])[:6], tzinfo=timezone.utc)
+        assert expected > datetime.now(timezone.utc)
 
     def test_last_modified_is_not_used_when_cache_control_present(self):
         resp = DummyResponse(
@@ -192,7 +187,8 @@ class TestModifiedUnitTests(object):
         )
         modified = self.heuristic.update_headers(resp)
         assert ["expires"] == list(modified.keys())
-        assert datetime(*parsedate(modified["expires"])[:6]) > datetime.now()
+        expected = datetime(*parsedate(modified["expires"])[:6], tzinfo=timezone.utc)
+        assert expected > datetime.now(timezone.utc)
 
     def test_warning_not_added_when_response_more_recent_than_24_hours(self):
         resp = DummyResponse(200, {"Date": self.now, "Last-Modified": self.week_ago})
